remote

package
v1.39.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 27, 2026 License: Apache-2.0 Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsDigestReference added in v1.36.1

func IsDigestReference(registryRef string) bool

IsDigestReference reports whether the given reference pins a specific image digest (e.g. "repo@sha256:abc...").

func NewTransport added in v1.36.1

func NewTransport(ctx context.Context) http.RoundTripper

NewTransport returns an HTTP transport that uses Docker Desktop proxy if available.

func NormalizeReference added in v1.36.1

func NormalizeReference(registryRef string) (string, error)

NormalizeReference parses an OCI reference and returns the normalized store key that Pull uses to store artifacts. This ensures that equivalent references (e.g. "agentcatalog/review-pr" and "index.docker.io/agentcatalog/review-pr:latest") map to the same key.

func Pull

func Pull(ctx context.Context, registryRef string, force bool, opts ...crane.Option) (string, error)

Pull pulls an artifact from a registry and stores it in the content store

func Push

func Push(ctx context.Context, reference string) error

Push pushes an artifact from the content store to an OCI registry

Types

This section is empty.

Jump to