jscommands

package
v1.114.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 21, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package jscommands wires pkg/js's goja-backed evaluator into the runtime, enabling ${...} JavaScript expressions in slash-command instructions:

jscommands.Register()

It is a separate package (called by teamloader, the docker-agent CLI and embeddedchat/defaults) so embedders that build teams in code and don't use JS command expressions never link the JS engine into their binary.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Register

func Register()

Register installs the goja-backed evaluator as the runtime's command evaluator. It is idempotent and safe to call from multiple goroutines.

Types

This section is empty.

Jump to