workingdir

package
v1.60.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 18, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckDirExists

func CheckDirExists(dir, kind string) error

CheckDirExists returns an error if the given directory does not exist or is not a directory. kind is used only in the error message.

func Default

func Default(agentWorkingDir string) string

Default returns the configured agent working directory or the process cwd.

func Resolve

func Resolve(toolsetWorkingDir, agentWorkingDir string) string

Resolve returns the effective working directory for a toolset process.

Types

This section is empty.

Jump to