Documentation
¶
Index ¶
- type Buffer
- type Map
- type Slice
- func (s *Slice[V]) All() []V
- func (s *Slice[V]) Append(value V)
- func (s *Slice[V]) Clear()
- func (s *Slice[V]) Find(predicate func(V) bool) (V, int)
- func (s *Slice[V]) Get(index int) (V, bool)
- func (s *Slice[V]) Length() int
- func (s *Slice[V]) Range(f func(index int, value V) bool)
- func (s *Slice[V]) Set(index int, value V) bool
- func (s *Slice[V]) Update(index int, f func(V) V) bool
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Buffer ¶ added in v1.35.0
type Buffer struct {
// contains filtered or unexported fields
}
Buffer is a concurrency-safe bytes.Buffer. It implements io.Writer so it can be used anywhere a plain buffer would, e.g. as the output target for a log handler or as subprocess stderr.
func (*Buffer) Drain ¶ added in v1.35.0
Drain returns the buffered content and resets the buffer atomically.
type Map ¶
type Map[K comparable, V any] struct { // contains filtered or unexported fields }
func NewMap ¶
func NewMap[K comparable, V any]() *Map[K, V]
Click to show internal directories.
Click to hide internal directories.