Documentation
¶
Index ¶
- func IsDigestReference(registryRef string) bool
- func NewTransport(ctx context.Context) http.RoundTripper
- func NormalizeReference(registryRef string) (string, error)
- func Pull(ctx context.Context, registryRef string, force bool, opts ...crane.Option) (string, error)
- func Push(ctx context.Context, reference string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsDigestReference ¶ added in v1.36.1
IsDigestReference reports whether the given reference pins a specific image digest (e.g. "repo@sha256:abc...").
func NewTransport ¶ added in v1.36.1
func NewTransport(ctx context.Context) http.RoundTripper
NewTransport returns an HTTP transport that uses Docker Desktop proxy if available.
func NormalizeReference ¶ added in v1.36.1
NormalizeReference parses an OCI reference and returns the normalized store key that Pull uses to store artifacts. This ensures that equivalent references (e.g. "agentcatalog/review-pr" and "index.docker.io/agentcatalog/review-pr:latest") map to the same key.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.