a2a

package
v1.60.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 18, 2026 License: Apache-2.0 Imports: 17 Imported by: 0

Documentation

Overview

Package a2a provides a toolset implementation for connecting to remote A2A agents.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateToolSet added in v1.60.0

func CreateToolSet(ctx context.Context, toolset latest.Toolset, runConfig *config.RuntimeConfig) (tools.ToolSet, error)

CreateToolSet is used by the tools registry.

Types

type Toolset

type Toolset struct {
	// contains filtered or unexported fields
}

Toolset implements tools.ToolSet for A2A remote agents.

func NewToolset

func NewToolset(name, url string, headers map[string]string) *Toolset

NewToolset creates a new A2A toolset for the given URL.

func (*Toolset) Instructions

func (t *Toolset) Instructions() string

Instructions returns instructions for using the A2A toolset.

func (*Toolset) Start

func (t *Toolset) Start(ctx context.Context) error

Start connects to the A2A agent and fetches the agent card.

func (*Toolset) Stop

func (t *Toolset) Stop(_ context.Context) error

Stop disconnects from the A2A agent.

func (*Toolset) Tools

func (t *Toolset) Tools(_ context.Context) ([]tools.Tool, error)

Tools returns the tools available from the remote A2A agent.

Jump to