Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExecuteFunc ¶
ExecuteFunc is a function that executes a command with an optional argument.
type Item ¶
type Item struct {
ID string
Label string
Description string
Category string
SlashCommand string
Execute ExecuteFunc
Hidden bool // Hidden commands work as slash commands but don't appear in the palette
// Immediate marks commands that should run as soon as they are submitted
// instead of being treated as ordinary queued chat input.
Immediate bool
}
Item represents a single command in the palette
Click to show internal directories.
Click to hide internal directories.